package tk.eclipse.plugin.xmleditor.editors;

import jp.aonir.fuzzyxml.FuzzyXMLDocument;
import jp.aonir.fuzzyxml.FuzzyXMLNode;
import jp.aonir.fuzzyxml.FuzzyXMLParser;
import jp.aonir.fuzzyxml.XPath;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import tk.eclipse.plugin.htmleditor.HTMLPlugin;

public class SearchXPathDialog extends Dialog {
	
	private Text xpath;
	private Text result;
	private Button button;
	private XMLEditor editor;
	
	protected SearchXPathDialog(Shell parentShell, XMLEditor editor) {
		super(parentShell);
		this.editor = editor;
	}

	@Override protected Control createContents(Composite parent) {
		Control control = super.createContents(parent);
		getShell().setDefaultButton(button);
		return control;
	}
	
	@Override protected void createButtonsForButtonBar(Composite parent) {
		createButton(parent, IDialogConstants.OK_ID, IDialogConstants.OK_LABEL, true);
	}

	@Override protected Control createDialogArea(Composite parent) {
		getShell().setText(HTMLPlugin.getResourceString("XMLEditor.XPathSearch"));
		
		Composite composite = new Composite(parent, SWT.NULL);
		composite.setLayout(new GridLayout(3, false));
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		Label label = new Label(composite, SWT.NULL);
		label.setText("&XPath:");
		
		xpath = new Text(composite, SWT.BORDER);
		xpath.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		xpath.addModifyListener(new ModifyListener(){
			public void modifyText(ModifyEvent arg0) {
				button.setEnabled(xpath.getText().length() > 0);
			}
		});
		
		button = new Button(composite, SWT.PUSH);
		button.setText(HTMLPlugin.getResourceString("Button.Search"));
		button.addSelectionListener(new SelectionAdapter(){
			@Override public void widgetSelected(SelectionEvent evt) {
				String query = xpath.getText();
				String xml = editor.getHTMLSource();
				FuzzyXMLDocument doc = new FuzzyXMLParser().parse(xml);
				
				try {
					FuzzyXMLNode[] nodes = XPath.selectNodes(doc.getDocumentElement(), query);
					StringBuffer sb = new StringBuffer();
//					sb.append("XPath: " + query + "\n");
//					sb.append("----\n");
					for(int i=0;i<nodes.length;i++){
						sb.append(nodes[i].toXMLString() + "\n");
					}
					result.setText(sb.toString());
					
				} catch(Exception ex){
					result.setText(ex.toString());
				}
				
				xpath.setFocus();
			}
		});
		button.setEnabled(false);
		
		result = new Text(composite, SWT.MULTI|SWT.V_SCROLL|SWT.H_SCROLL|SWT.BORDER);
		GridData gd = new GridData(GridData.FILL_BOTH);
		gd.horizontalSpan = 3;
		result.setLayoutData(gd);
		result.setEditable(false);
		result.setBackground(Display.getDefault().getSystemColor(SWT.COLOR_WHITE));
		
		return composite;
	}

	@Override protected Point getInitialSize() {
		return new Point(400, 300);
	}

	@Override protected int getShellStyle() {
		return super.getShellStyle() | SWT.RESIZE;
	}
	
	
	
}
